@@ -1,5 +1,5 @@
 package HTTP::API::Client;
-$HTTP::API::Client::VERSION = '0.03';
+$HTTP::API::Client::VERSION = '0.04';
 use strict;
 use warnings;
 
@@ -156,7 +156,7 @@ has ssl_verify => (
 );
 
 sub _build_ssl_verify {
-    return $ENV{SSL_VERIFY} // 0;
+    return _smart_or($ENV{SSL_VERIFY}, 0);
 }
 
 has retry => (
@@ -188,9 +188,9 @@ has retry_config => (
 
 sub _build_retry_config {
     return {
-        fail_response => $ENV{RETRY_FAIL_RESPONSE} // 0,
+        fail_response => _smart_or($ENV{RETRY_FAIL_RESPONSE}, 0),
         fail_status => $ENV{RETRY_FAIL_STATUS} || q{},
-        delay => $ENV{RETRY_DELAY} // 5,
+        delay => _smart_or($ENV{RETRY_DELAY}, 5),
     };
 }
 
@@ -269,11 +269,10 @@ sub send {
     my $base_url     = $self->base_url;
     my $url          = $base_url ? $base_url . $path : $path;
     my $req          = $self->_request( $method, $url, $data, $headers );
-    my $retry_count  = $self->retry->{count} // 1;
+    my $retry_count  = _smart_or($self->retry->{count}, 1);
     my %retry_status = %{ $self->retry->{status} || {} };
-    my $retry_delay  = $self->retry->{delay} // 5;
+    my $retry_delay  = _smart_or($self->retry->{delay}, 5);
     my %debug        = %{ $self->debug_flags || {} };
-    $DB::single=2;
 
     my $response;
 
@@ -448,4 +447,10 @@ sub _basic_authenticator {
     $req->headers->authorization_basic( $username, $password );
 }
 
+sub _smart_or {
+    my $default_value = shift;
+    my $or_value    = shift;
+    return defined($default_value) && length($default_value) ? $default_value : $or_value;
+}
+
 1;
